function [Df] = Df_ch(x)
%   INPUT DATA
% x: the vector of cosine Fourier coefficients of the solution
%
%   OUTPUT DATA
% Df: The Jacobian matrix (the derivative) of the map f at the point x
%
m=length(x)-2;
lambda=x(1);
u=x(3:end);
L=pi;

Df_lambda=((L^2/lambda^2)*(0:m-1).^2)'.*u;
Df_c=[-1;zeros(m-1,1)];
Df_u=f_ch1d_xFFT(lambda,u);

Df = [Df_lambda Df_c Df_u];

end

function [J]=f_ch1d_xFFT(lambda,u)
m=length(u);
L=pi;

v=flipdim(u(2:m),1);

tu=[zeros(m,1);v;u;zeros(m,1)];

TU=ifft(ifftshift(tu));

F=fftshift(fft(TU.*TU));

quad_sum=real((4*m-1)*F(m+1:4*m-2));

J=zeros(m);

for s=0:m-1 
    J(s+1,1)=isequal(s,0)*(1-(1/lambda)*L^2*s^2)-(3/2)*(quad_sum(s+m)+quad_sum(s+m));
    for t=1:m-1
        J(s+1,t+1)=isequal(s,t)*(1-(1/lambda)*L^2*s^2)-3*(quad_sum(s-t+m)+quad_sum(s+t+m));
    end
end

end