function distrVerification(node,simplex,job,jobsNum)
%   INPUT DATA
% node:     database of nodes
% simplex:  database of simplices
% job:      job number
% jobsNum:  total number of jobs
%
%   OUTPUT DATA
% output is provided on files, see below
%
%   EXAMPLE
% distrVerification(node,simplex,2,500) will split the set of simplices
% evenly into 500 subsets (see code below), and the simplices within the
% second subset will be verified.
%
%   NOTE
% output will be saved on files; this routine is intended to be used in a
% Distributed Computing Cluster, under a UNIX environment, and relies on
% the existence of a specific directory structure.
%
% build vector of indices that need to be verified
simpNum=size(simplex.node,2);
simpIndVec=job:jobsNum:simpNum;
% below:
% flag=0     verified at first attempt
% flag=p>0   verified after p splits
% flag=-1    NOT verified within prescribed number of splits
flagsVec=[];
tic
%%
str=num2str(max([1 ceil(log10(jobsNum+1))]));
stringOpenFile1=['fid%0' str '.0fof%0' str '.0f=fopen('];
stringOpenFile2=['''screen_output_%0' str '.0fof%0' str '.0f.txt'''];
stringFid=['fid%0' str '.0fof%0' str '.0f'];
eval([sprintf(stringOpenFile1,job,jobsNum) sprintf(stringOpenFile2,job,jobsNum) ',''wt'');']);
fprintf(eval(sprintf(stringFid,job,jobsNum)),'\tjob %1.0f of %1.0f,\ttest started on %s',job,jobsNum,datestr(now));
stringDirName=['./job%0' str '.0f/intlab/']; dirName=sprintf(stringDirName,job);
unix(['rm ' dirName '*.mat']);
eval(['addpath ' dirName ])
startintlab
s=2; M=3*(length(node.coord{1})-2)-2;
[alphaM,epsilon]=int_estimates_cod(s,M);
%%
counter=0;
for ind=simpIndVec
    counter=counter+1;
    fprintf(eval(sprintf(stringFid,job,jobsNum)),...
        '\n\tjob %1.0f of %1.0f,\tverifying simplex %1.0f out of %1.0f',...
        job,jobsNum,counter,length(simpIndVec));
    bx0=node.coord{simplex.node{ind}(1)};
    bx1=node.coord{simplex.node{ind}(2)};
    bx2=node.coord{simplex.node{ind}(3)};
    PHI_0=node.frame{simplex.node{ind}(1)};
    PHI_1=node.frame{simplex.node{ind}(2)};
    PHI_2=node.frame{simplex.node{ind}(3)};
    [valid]=verifySimplex(bx0,bx1,bx2,PHI_0,PHI_1,PHI_2,alphaM,epsilon);
    if valid
        flagsVec=[flagsVec;ind,0];
        fprintf(eval(sprintf(stringFid,job,jobsNum)),...
            '\n\tjob %1.0f of %1.0f,\tsimplex with index %1.0f verified without splitting',...
            job,jobsNum,ind);
        continue
    end
    [valid,splitCounter]=splitAndVerify(ind,node,simplex,alphaM,epsilon);
    if valid
        flagsVec=[flagsVec;ind,splitCounter];
        fprintf(eval(sprintf(stringFid,job,jobsNum)),...
            '\n\tjob %1.0f of %1.0f,\tsimplex with index %1.0f verified after %1.0f splitting(s)',...
            job,jobsNum,ind,splitCounter);
        continue
    end
    flagsVec=[flagsVec;ind,-1];
    fprintf(eval(sprintf(stringFid,job,jobsNum)),...
        '\n\tjob %1.0f of %1.0f,\tsimplex with index %1.0f failed verification',...
        job,jobsNum,ind);
end
tStop=toc;
stringFileName=['output_file_%0' str '.0fof%0' str '.0f'];
save(sprintf(stringFileName,job,jobsNum),'flagsVec','tStop');
fclose(eval(sprintf(stringFid,job,jobsNum)));