function [alphaM,epsilon]=int_estimates_cod(s,M)
%   INPUT DATA
% s: algebraic decay rate of the Banach space Omega^s
% M: the computational parameter as introduced in Lemmata 5.2 and 5.3
%
%   OUTPUT DATA
% alphaM: the asymptotic analytic estimate from Lemma 5.3
% epsilon: the vector (epsilon_0,epsilon_1,...,epsilon_{M-1}) in R^M of
%          estimates from Lemma 5.2 

i1=intval('1');
i2=intval('2');
i3=intval('3');
i4=intval('4');
i6=intval('6');
is=intval(s);
ipi=midrad(3.14159265358979323,1e-16);
iM=intval(M);

Power=3;

gamma_M=i2*(iM/(iM-i1))^is+(i4*log(iM-i2)/iM+(ipi^2-i6)/i3)*(i2/iM+i1/i2)^(is-i2);

a0=intval(zeros(1,Power));     % We allocate memory for \alpha_k (k=0)
a=intval(zeros(M,Power));      % We allocate memory for \alpha_k (k>0)

%%%%%%%%%%%%%%%%
%              %
%   Case p=2   %    
%              %
%%%%%%%%%%%%%%%%

a0(1,2) = i1 + i2*sum(intval(1:M).^(-i2*is)) + i1/(iM^(i2*is-i1)*(i2*is-i1));

for k=1:M-1  
    ik=intval(k);
    a(k,2) = i2*ik^is*sum(intval(1:M).^(-is).*(ik+intval(1:M)).^(-is)) + ...
             i2*ik^is/((ik+iM)^is*iM^(is-i1)*(is-i1)) + i2 + ik^is*sum(intval(1:k-1).^(-is).*(ik-intval(1:k-1)).^(-is));
end

a(M,2) = i2 + i2*sum(intval(1:M).^(-is)) + i2/(iM^(is-i1)*(is-i1)) + gamma_M;

%%%%%%%%%%%%%%%%%%
%                %
%   Cases p>=3   %    
%                %
%%%%%%%%%%%%%%%%%%

for p=3:Power
   
    %%% Case k=0 %%%
    
    a0(1,p) = a0(1,p-1) + i2*sum(a(1:M-1,p-1)'.*intval(1:M-1).^(-i2*is)) + i2*a(M,p-1)/((iM-i1)^(i2*is-i1)*(i2*is-i1));
    
    %%% Cases k=1,...,M-1 %%%
    for k=1:M-1
        ik=intval(k);
        sum2 = sum(a(k+(1:M-k),p-1)'*ik^is./(intval(1:M-k).^is.*intval(k+(1:M-k)).^is));
        sum3 = sum((a(1:k-1,p-1)'*ik^is)./(intval(1:k-1).^is.*intval(k-(1:k-1)).^is));
        sum4 = sum(a(1:M,p-1)'*ik^is./(intval(1:M).^is.*intval(k+(1:M)).^is));
        
        a(k,p)=sum2+a(M,p-1)*ik^is/((iM+i1)^is*(iM-ik)^(is-i1)*(is-i1))+sum3+sum4 ...
               +a(M,p-1)*ik^is/((iM+ik+i1)^is*iM^(is-i1)*(is-i1))+a(k,p-1)+a0(1,p-1);
    end
    
    %%% Case k=M %%%
    
    sum5 = sum(a(1:M-1,p-1)'.*intval(1:M-1).^(-is));
    
    Sigma_star_a = sum(a(1:M-1,p-1)'*iM^is./(intval(1:M-1).^is.*(iM-intval(1:M-1)).^is)) ...
                   + a(M,p-1)*(gamma_M-sum(intval(1:M-1).^(-is)));
    Sigma_star_b = intval(max(mag(a(1:M,p-1))))*gamma_M;
        
    Sigma_star=intval(min(mag(Sigma_star_a),mag(Sigma_star_b)));
    
    a(M,p)=a(M,p-1)*sum(intval(1:M).^(-is)) + i2*a(M,p-1)/(iM^(is-i1)*(is-i1)) + Sigma_star + sum5 + a(M,p-1) + a0(1,p-1);
    
end

ALPHA=[a0;a];
ALPHA(:,1)=[];

epsilon=intval(zeros(M,1));

for k=0:M-1
    ik=intval(k);
    sum6=0;
    for k1=M:M+k
        ik1=intval(k1);
        sum6=sum6+ALPHA(k1-k,2)/(ik1^is*(ik1-ik)^is);
    end
    epsilon(k+1,1)=ALPHA(M,2)/(iM^(i2*is)) + sum6 + ALPHA(M,2)/((iM+i1)^is*(is-i1))*(i1/(iM-ik)^(is-i1)+i1/(iM+ik)^(is-i1));
end

alphaM=ALPHA(end,2);

end
