function [valid,counter]=splitAndVerify(simpInd,node,simplex,alphaM,epsilon);
%   INPUT DATA
% simpInd: index of the simplex that needs to be splitted and verified
% node, simplex: databases of nodes and simplices
%
%   OUTPUT DATA
% valid: true if verification after splittings was succesfull
% counter: number of splittings performed
%
%   NOTE
% the simplex is split in 4 triangles by adding one point in the middle of
% each edge; each triangle, then, undergoes verification; triangles that
% still fail verification undergo the same process (up to a maximum number
% of splittings); the database is NOT modified
nodesInd=simplex.node{simpInd};
bx0=node.coord{nodesInd(1)};
bx1=node.coord{nodesInd(2)};
bx2=node.coord{nodesInd(3)};
PHI_0=node.frame{nodesInd(1)};
PHI_1=node.frame{nodesInd(2)};
PHI_2=node.frame{nodesInd(3)};
%% reorder the nodes so that the node on which we base the verificarion 
%  minimizes the distance between reference frames at the endpoints of the
%  edges attached to it
d01=norm(PHI_0-PHI_1,'fro');
d02=norm(PHI_0-PHI_2,'fro');
d12=norm(PHI_1-PHI_2,'fro');
[~,dMaxInd]=max([d12 d02 d01]);
if dMaxInd>1
    bx_mat=[bx0 bx1 bx2];
    bx_mat(:,[1 dMaxInd])=bx_mat(:,[dMaxInd 1]);
    PHI_mat=[PHI_0 PHI_1 PHI_2];
    PHI_mat(:,[1 2 2*dMaxInd-1 2*dMaxInd])=PHI_mat(:,[2*dMaxInd-1 2*dMaxInd 1 2]);
    bx0=bx_mat(:,1); bx1=bx_mat(:,2); bx2=bx_mat(:,3);
    PHI_0=PHI_mat(:,[1 2]); PHI_1=PHI_mat(:,[3 4]); PHI_2=PHI_mat(:,[5 6]);
end
%%
bx_all{1}=[bx0 bx1 bx2]; PHI_all{1}=[PHI_0 PHI_1 PHI_2];
counter=0;
while size(bx_all,2) && counter<21
    counter=counter+1;
    [bx_all,PHI_all]=verifyTriangle(bx_all,PHI_all,alphaM,epsilon);
end
if ~size(bx_all,2)
    valid=1;
else
    fprintf('reached maximum number of splittings without succesfull verification')
    valid=0;
end
end

function [bx_all,PHI_all]=verifyTriangle(bx_all,PHI_all,alphaM,epsilon)
bx0=bx_all{1}(:,1); bx1=bx_all{1}(:,2); bx2=bx_all{1}(:,3);
PHI_0=PHI_all{1}(:,[1 2]); PHI_1=PHI_all{1}(:,[3 4]); PHI_2=PHI_all{1}(:,[5 6]);
bx01=intval(.5)*(intval(bx0)+intval(bx1));
bx02=intval(.5)*(intval(bx0)+intval(bx2));
bx12=intval(.5)*(intval(bx1)+intval(bx2));
PHI_01=intval(.5)*(intval(PHI_0)+intval(PHI_1));
PHI_02=intval(.5)*(intval(PHI_0)+intval(PHI_2));
PHI_12=intval(.5)*(intval(PHI_1)+intval(PHI_2));
bx_all(1)=[]; PHI_all(1)=[];
% verify the four triangles
[valid1]=verifySimplex(bx0,bx01,bx02,PHI_0,PHI_01,PHI_02,alphaM,epsilon);
if ~valid1
    bx_all{size(bx_all,2)+1}=[bx0 bx01 bx02];
    PHI_all{size(PHI_all,2)+1}=[PHI_0 PHI_01 PHI_02];
end
[valid2]=verifySimplex(bx1,bx01,bx12,PHI_1,PHI_01,PHI_12,alphaM,epsilon);
if ~valid2
    bx_all{size(bx_all,2)+1}=[bx1 bx01 bx12];
    PHI_all{size(PHI_all,2)+1}=[PHI_1 PHI_01 PHI_12];
end
[valid3]=verifySimplex(bx2,bx02,bx12,PHI_2,PHI_02,PHI_12,alphaM,epsilon);
if ~valid3
    bx_all{size(bx_all,2)+1}=[bx2 bx02 bx12];
    PHI_all{size(PHI_all,2)+1}=[PHI_2 PHI_02 PHI_12];
end
[valid4]=verifySimplex(bx01,bx02,bx12,PHI_01,PHI_02,PHI_12,alphaM,epsilon);
if ~valid4
    bx_all{size(bx_all,2)+1}=[bx01 bx02 bx12];
    PHI_all{size(PHI_all,2)+1}=[PHI_01 PHI_02 PHI_12];
end
end